@@ -1,4 +1,4 @@
-## this adds test to toplevel's ..statusBarText
+## this adds text to toplevel's ..statusBarText
 ## and puts widget into ..statusBar so that ..shown can be set.
 ## if toplevel is a
 ## statusbar is different from gstatusbar -- does not pop to last message
@@ -11,8 +11,6 @@ gstatusbar <- function(text = "", container=NULL, ...) {
 
   ## where to put. Here we make a distinction between
   ## subwindows and windows (which are toplevel component
-
-  
   if(inherits(container,"gSubwindow")) {
     widget$sbContainer <- container
   } else {
@@ -26,6 +24,16 @@ gstatusbar <- function(text = "", container=NULL, ...) {
   ## for statusbar, we get ID not from adding, but directly
   widget$ID <- container$newID()
 
+
+  ## need to load in ux code, as of 3.0 status bar is not ext native
+  widget$scripts <- function(.) {
+    f <- system.file("javascript","ext.ux.statusbar.js", package="gWidgetsWWW")
+    out <- paste(readLines(f), collapse="\n")
+    
+    return(out)
+  }
+
+  
   ## helper to get status bar by its ID
   widget$getSBJS <- function(.) {
     out <- String() +
